@@ -164,15 +164,17 @@ void WorkerIntegration::toggleActAsAdmin()
                                  KStandardGuiItem::cancel());
         warningDialog.setDontAskAgainText(i18nc("@option:check", "Do not warn me about these risks again"));
 
-        risksAccepted = warningDialog.exec() != 4 /* Cancel */;
-        if (warningDialog.isDontAskAgainChecked()) {
-            KMessageBox::saveDontShowAgainContinue(warningDontShowAgainName);
-        }
+        risksAccepted = warningDialog.exec() == KMessageDialog::PrimaryAction;
 
         if (!risksAccepted) {
+            url.setScheme(QStringLiteral("file"));
             updateActAsAdminAction(); // Uncheck the action
             return;
         }
+
+        if (warningDialog.isDontAskAgainChecked()) {
+            KMessageBox::saveDontShowAgainContinue(warningDontShowAgainName);
+        }
     }
 
     url.setScheme(QStringLiteral("admin"));
