@@ -14,6 +14,7 @@
 #include "dolphinremoveaction.h"
 #include "dolphinviewcontainer.h"
 #include "global.h"
+#include "settings/dolphinsettingsdialog.h"
 #include "trash/dolphintrash.h"
 #include "views/dolphinview.h"
 
@@ -127,6 +128,10 @@ void DolphinContextMenu::addTrashContextMenu()
     });
     emptyTrashAction->setEnabled(!Trash::isEmpty());
 
+    connect(&Trash::instance(), &Trash::emptinessChanged, this, [emptyTrashAction](bool isEmpty) {
+        emptyTrashAction->setEnabled(!isEmpty);
+    });
+
     // Insert 'Sort By' and 'View Mode'
     if (ContextMenuSettings::showSortBy() || ContextMenuSettings::showViewMode()) {
         addSeparator();
@@ -139,8 +144,18 @@ void DolphinContextMenu::addTrashContextMenu()
     }
 
     addSeparator();
-    QAction *propertiesAction = m_mainWindow->actionCollection()->action(QStringLiteral("properties"));
-    addAction(propertiesAction);
+
+    auto *configureTrashAction = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18nc("@action:inmenu", "Configure Trash…"), this);
+    connect(configureTrashAction, &QAction::triggered, this, &DolphinContextMenu::configureTrash);
+    addAction(configureTrashAction);
+}
+
+void DolphinContextMenu::configureTrash()
+{
+    DolphinSettingsDialog *settingsDialog = new DolphinSettingsDialog(m_baseUrl, m_mainWindow);
+    settingsDialog->setCurrentPage(settingsDialog->trashSettings);
+    settingsDialog->setAttribute(Qt::WA_DeleteOnClose);
+    settingsDialog->show();
 }
 
 void DolphinContextMenu::addTrashItemContextMenu()
